==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/update_subnet_bandwidth_control_list_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubnetBandwidthControlListReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'control_mode': 'str',
        'add_control_list': 'list[str]',
        'remove_control_list': 'list[str]'
    }

    attribute_map = {
        'control_mode': 'control_mode',
        'add_control_list': 'add_control_list',
        'remove_control_list': 'remove_control_list'
    }

    def __init__(self, control_mode=None, add_control_list=None, remove_control_list=None):
        """UpdateSubnetBandwidthControlListReq

        The model defined in huaweicloud sdk

        :param control_mode: 控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。
        :type control_mode: str
        :param add_control_list: 待添加的桌面。
        :type add_control_list: list[str]
        :param remove_control_list: 待删除的桌面。
        :type remove_control_list: list[str]
        """
        
        

        self._control_mode = None
        self._add_control_list = None
        self._remove_control_list = None
        self.discriminator = None

        if control_mode is not None:
            self.control_mode = control_mode
        if add_control_list is not None:
            self.add_control_list = add_control_list
        if remove_control_list is not None:
            self.remove_control_list = remove_control_list

    @property
    def control_mode(self):
        """Gets the control_mode of this UpdateSubnetBandwidthControlListReq.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :return: The control_mode of this UpdateSubnetBandwidthControlListReq.
        :rtype: str
        """
        return self._control_mode

    @control_mode.setter
    def control_mode(self, control_mode):
        """Sets the control_mode of this UpdateSubnetBandwidthControlListReq.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :param control_mode: The control_mode of this UpdateSubnetBandwidthControlListReq.
        :type control_mode: str
        """
        self._control_mode = control_mode

    @property
    def add_control_list(self):
        """Gets the add_control_list of this UpdateSubnetBandwidthControlListReq.

        待添加的桌面。

        :return: The add_control_list of this UpdateSubnetBandwidthControlListReq.
        :rtype: list[str]
        """
        return self._add_control_list

    @add_control_list.setter
    def add_control_list(self, add_control_list):
        """Sets the add_control_list of this UpdateSubnetBandwidthControlListReq.

        待添加的桌面。

        :param add_control_list: The add_control_list of this UpdateSubnetBandwidthControlListReq.
        :type add_control_list: list[str]
        """
        self._add_control_list = add_control_list

    @property
    def remove_control_list(self):
        """Gets the remove_control_list of this UpdateSubnetBandwidthControlListReq.

        待删除的桌面。

        :return: The remove_control_list of this UpdateSubnetBandwidthControlListReq.
        :rtype: list[str]
        """
        return self._remove_control_list

    @remove_control_list.setter
    def remove_control_list(self, remove_control_list):
        """Sets the remove_control_list of this UpdateSubnetBandwidthControlListReq.

        待删除的桌面。

        :param remove_control_list: The remove_control_list of this UpdateSubnetBandwidthControlListReq.
        :type remove_control_list: list[str]
        """
        self._remove_control_list = remove_control_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubnetBandwidthControlListReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/update_subnet_bandwidth_control_list_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateSubnetBandwidthControlListReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'control_mode': 'str',
        'add_control_list': 'list[str]',
        'remove_control_list': 'list[str]'
    }

    attribute_map = {
        'control_mode': 'control_mode',
        'add_control_list': 'add_control_list',
        'remove_control_list': 'remove_control_list'
    }

    def __init__(self, control_mode=None, add_control_list=None, remove_control_list=None):
        r"""UpdateSubnetBandwidthControlListReq

        The model defined in huaweicloud sdk

        :param control_mode: 控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。
        :type control_mode: str
        :param add_control_list: 待添加的桌面。
        :type add_control_list: list[str]
        :param remove_control_list: 待删除的桌面。
        :type remove_control_list: list[str]
        """
        
        

        self._control_mode = None
        self._add_control_list = None
        self._remove_control_list = None
        self.discriminator = None

        if control_mode is not None:
            self.control_mode = control_mode
        if add_control_list is not None:
            self.add_control_list = add_control_list
        if remove_control_list is not None:
            self.remove_control_list = remove_control_list

    @property
    def control_mode(self):
        r"""Gets the control_mode of this UpdateSubnetBandwidthControlListReq.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :return: The control_mode of this UpdateSubnetBandwidthControlListReq.
        :rtype: str
        """
        return self._control_mode

    @control_mode.setter
    def control_mode(self, control_mode):
        r"""Sets the control_mode of this UpdateSubnetBandwidthControlListReq.

        控制模式 - BLACK：黑名单控制。 - WHITE：白名单控制。

        :param control_mode: The control_mode of this UpdateSubnetBandwidthControlListReq.
        :type control_mode: str
        """
        self._control_mode = control_mode

    @property
    def add_control_list(self):
        r"""Gets the add_control_list of this UpdateSubnetBandwidthControlListReq.

        待添加的桌面。

        :return: The add_control_list of this UpdateSubnetBandwidthControlListReq.
        :rtype: list[str]
        """
        return self._add_control_list

    @add_control_list.setter
    def add_control_list(self, add_control_list):
        r"""Sets the add_control_list of this UpdateSubnetBandwidthControlListReq.

        待添加的桌面。

        :param add_control_list: The add_control_list of this UpdateSubnetBandwidthControlListReq.
        :type add_control_list: list[str]
        """
        self._add_control_list = add_control_list

    @property
    def remove_control_list(self):
        r"""Gets the remove_control_list of this UpdateSubnetBandwidthControlListReq.

        待删除的桌面。

        :return: The remove_control_list of this UpdateSubnetBandwidthControlListReq.
        :rtype: list[str]
        """
        return self._remove_control_list

    @remove_control_list.setter
    def remove_control_list(self, remove_control_list):
        r"""Sets the remove_control_list of this UpdateSubnetBandwidthControlListReq.

        待删除的桌面。

        :param remove_control_list: The remove_control_list of this UpdateSubnetBandwidthControlListReq.
        :type remove_control_list: list[str]
        """
        self._remove_control_list = remove_control_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSubnetBandwidthControlListReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
